@@ -5,9 +5,9 @@ use strict;
 use warnings;
 use parent qw/Exporter/;
 
-our @EXPORT    = qw/strike/; ## no critic (ProhibitAutomaticExportation)
-our @EXPORT_OK = qw/strike_query strike/;
-our $VERSION = '0.001002';
+our @EXPORT    = qw/strike strike_search/; ## no critic (ProhibitAutomaticExportation)
+our @EXPORT_OK = qw/strike_query strike strike_search/;
+our $VERSION = '0.002';
 our $BASE_URL = 'http://getstrike.net/api/torrents/';
 
 use JSON::MaybeXS qw/decode_json/;
@@ -17,18 +17,35 @@ use WebService::Strike::Torrent;
 
 sub _ht { HTTP::Tiny->new(agent => "WebService-Strike/$VERSION") }
 
-sub strike_query {
-	my (@hashes) = @_;
-	my $url = "$BASE_URL/info/?hashes=" . join ',', map { uc } @hashes;
+sub _query {
+	my ($url) = @_;
+
 	my $ht = _ht;
 	my $response = $ht->get($url);
 	die $response unless $response->{success}; ## no critic (RequireCarping)
 	$response = decode_json $response->{content};
 
 	die $response unless ref $response eq 'ARRAY'; ## no critic (RequireCarping)
+	map { WebService::Strike::Torrent->new($_) } @{$response->[1]};
+}
+
+sub strike_query {
+	my (@hashes) = @_;
+	my $url = "$BASE_URL/info/?hashes=" . join ',', map { uc } @hashes;
+
 	my $sorter = sbe(\@hashes, {xform => sub { $_[0]->hash }});
-	my @torrents = map { WebService::Strike::Torrent->new($_) } @{$response->[1]};
-	@torrents = $sorter->(@torrents);
+	my @torrents = $sorter->(_query $url);
+	wantarray ? @torrents : $torrents[0]
+}
+
+sub strike_search {
+	my ($query, $full, %args) = @_;
+	$args{q} = $query;
+	my $url = "$BASE_URL/search/?" . HTTP::Tiny->www_form_urlencode(\%args);
+
+	my @torrents = _query $url;
+	@torrents = $torrents[0] unless wantarray;
+	@torrents = strike_query map { $_->hash } @torrents if $full;
 	wantarray ? @torrents : $torrents[0]
 }
 
@@ -52,6 +69,14 @@ WebService::Strike - Get torrent info from getstrike.net API
   my $torrent = $t->torrent;   # Returns the torrent file
   $t->torrent('file.torrent'); # Downloads the torrent file to 'file.torrent'
 
+  my @debian = strike_search 'Debian';
+  say 'Found ' . @debian . ' torrents matching "Debian"';
+  say 'First torrent has info hash ' . $debian[0]->hash;
+
+  my $mp = strike_search 'Modern perl', 1;
+  say 'Torrent has ' . $mp->count . ' files. They are:';
+  say join ' ', @{$mp->file_names};
+
 =head1 DESCRIPTION
 
 Strike API is a service for getting information about a torrent given
@@ -61,14 +86,27 @@ its info hash. WebService::Strike is a wrapper for this service.
 
 =item B<strike>(I<@info_hashes>)
 
-Returns a list of hashrefs, one for each info hash. The hashrefs are
-blessed into the L<WebService::Strike::Torrent> package. Dies in case
-of error.
+Returns a list of L<WebService::Strike::Torrent> objects in list
+context or the first such object in scalar context. Dies in case of
+error.
 
 =item B<strike_query>
 
 Alias for B<strike>. Not exported by default.
 
+=item B<strike_search>(I<$search_term>, [I<$full>])
+
+Searches for torrents given a search term. Returns a list of
+L<WebService::Strike::Torrent> objects in list context or the first
+such object in scalar context.
+
+If I<$full> is false (default), the returned objects will be
+incomplete: their B<file_names> and B<file_lengths> accessors will
+return undef.
+
+If I<$full> is true, B<strike> will be called with the info hashes of
+the found torrents, thus obtaining complete objects.
+
 =back
 
 =head1 SEE ALSO
